@@ -18,10 +18,20 @@ def get_errors_fails(report_path: str):
 
     fail_error = [fail.split('----------------------------------------------------------------------')[0]
                 for fail in list_fails]
+    
+    error_dict = {}
 
-    errors = [e.split('ERROR: ')[1].split(' (')[0] for e in fail_error if e.startswith('\nERROR')]
-    fails = [f.split('FAIL: ')[1].split(' (')[0] for f in fail_error if f.startswith('\nFAIL')]
-    return errors, fails
+    for error in list_fails:
+        if error.startswith('\nERROR'):
+            fail_error = error.split('----------------------------------------------------------------------')[0].split('ERROR: ')[1].split(' (')[0]
+            message = ' '.join(error.split('----------------------------------------------------------------------')[1].split(': ')[-2:]).strip()
+            error_dict[fail_error] = message
+        elif error.startswith('\nFAIL'):
+            fail_error = error.split('----------------------------------------------------------------------')[0].split('FAIL: ')[1].split(' (')[0]
+            message = error.split('----------------------------------------------------------------------')[1].split(' : ')[1].strip()
+            error_dict[fail_error] = message
+
+    return error_dict
 
 def mark_complete(task_id: str, message=None):
     data = {
