@@ -1,7 +1,7 @@
-from .verify import get_errors_fails, mark_incomplete, mark_complete
+from verify import get_errors_fails, mark_incomplete, mark_complete
+
+errors = get_errors_fails('milestone_1.txt')
 
-errors, fails = get_errors_fails('milestone_1.txt')
-errors.extend(fails)
 task1_id = '3f496682-807d-4ba4-aa64-c09ebba9b83a' # Download the template
 task2_id = '4c240b07-e0b2-421a-9cfc-2df6858c9f54' # Create your solution file
 task3_id = '62158fc2-ba1d-49f4-aee0-66ec01f63baa' # Fill in the `ask_letter` function
@@ -24,6 +24,3 @@ elif 'test_presence_ask_letter' in errors:
     # mark_incomplete(task3_id, message='The play_game() function is not using the ask_letter method')
     mark_incomplete(task3_id)
 
-
-    
-# print(errors)
